@@ -25,6 +25,10 @@ except ImportError:
     from yaml import SafeDumper  # type: ignore
 
 
+class BadMatch(Exception):
+    pass
+
+
 def machine_info():
     info = {
         'software_versions': {
@@ -346,7 +350,13 @@ def remap_lineage_doc(root, mk_node, **kwargs):
     if not isinstance(root, SimpleDocNav):
         root = SimpleDocNav(root)
 
-    return visit(root)
+    try:
+        return visit(root)
+    except BadMatch as e:
+        if root.id not in str(e):
+            raise BadMatch(f"Error loading lineage dataset: {e}") from None
+        else:
+            raise
 
 
 def dedup_lineage(root):
