@@ -13,7 +13,7 @@ from collections import OrderedDict
 
 from datacube.utils import gen_password
 from datacube.config import LocalConfig
-from datacube.index.index import Index
+from datacube.index import Index
 from datacube.ui import click as ui
 from datacube.ui.click import cli
 from datacube.utils.serialise import SafeDatacubeDumper
