@@ -1,3 +1,7 @@
+# This file is part of the Open Data Cube, see https://opendatacube.org for more information
+#
+# Copyright (c) 2015-2020 ODC Contributors
+# SPDX-License-Identifier: Apache-2.0
 from typing import Optional, Dict, Any, Tuple
 from urllib.parse import urlparse
 
@@ -77,7 +81,8 @@ class BandInfo:
     def __init__(self,
                  ds: Dataset,
                  band: str,
-                 uri_scheme: Optional[str] = None):
+                 uri_scheme: Optional[str] = None,
+                 extra_dim_index: Optional[int] = None):
         try:
             mp, = ds.type.lookup_measurements([band]).values()
         except KeyError:
