@@ -18,7 +18,7 @@ from dateutil import tz
 
 from datacube.drivers.postgres import PostgresDb
 from datacube.index.exceptions import MissingRecordError
-from datacube.index.index import Index
+from datacube.index import Index
 from datacube.model import Dataset, MetadataType
 
 _telemetry_uuid = UUID('4ec8fe97-e8b9-11e4-87ff-1040f381a756')
@@ -347,7 +347,6 @@ def test_index_dataset_with_sources(index, default_metadata_type):
         index.datasets.add(child, sources_policy=p)
 
 
-@pytest.mark.parametrize('datacube_env_name', ('datacube', ), indirect=True)
 def test_index_dataset_with_location(index: Index, default_metadata_type: MetadataType):
     first_file = Path('/tmp/first/something.yaml').absolute()
     second_file = Path('/tmp/second/something.yaml').absolute()
