@@ -43,12 +43,12 @@ from datacube.utils.geometry._base import (
     bounding_box_in_pixel_domain,
     geobox_intersection_conservative,
     geobox_union_conservative,
-    _guess_crs_str,
     force_2d,
     _align_pix,
     _round_to_res,
     _norm_crs,
     _norm_crs_or_error,
+    _make_crs_key,
 )
 from datacube.testutils.geom import (
     epsg4326,
@@ -362,8 +362,8 @@ def test_shapely_wrappers():
     assert x.typecode == y.typecode
     assert x.typecode == 'd'
 
-    assert (poly | poly) == poly
-    assert (poly & poly) == poly
+    assert ((poly | poly) ^ poly).is_empty
+    assert ((poly & poly) ^ poly).is_empty
     assert (poly ^ poly).is_empty
     assert (poly - poly).is_empty
 
@@ -949,7 +949,7 @@ def test_crs():
 
     crs2 = CRS(crs)
     assert crs2 == crs
-    assert crs.proj is crs2.proj
+    assert crs.proj == crs2.proj
 
     assert epsg4326.valid_region == geometry.box(-180, -90, 180, 90, epsg4326)
     assert epsg3857.valid_region.crs == epsg4326
@@ -1475,9 +1475,9 @@ def test_crs_hash():
 
 
 def test_base_internals():
-    assert _guess_crs_str(CRS("epsg:3577")) == 'EPSG:3577'
+    assert _make_crs_key("epsg:3577") == "EPSG:3577"
     no_epsg_crs = CRS(SAMPLE_WKT_WITHOUT_AUTHORITY)
-    assert _guess_crs_str(no_epsg_crs) == no_epsg_crs.to_wkt()
+    assert _make_crs_key(no_epsg_crs.proj) == no_epsg_crs.proj.to_wkt()
 
     gjson_bad = {'type': 'a', 'coordinates': [1, [2, 3, 4]]}
     assert force_2d(gjson_bad) == {'type': 'a', 'coordinates': [1, [2, 3]]}
@@ -1515,6 +1515,20 @@ def test_crs_units_per_degree():
     assert crs_units_per_degree('EPSG:3857', -180, 0) == approx(111319.49, 0.5)
 
 
+def test_rio_crs__no_epsg():
+    import rasterio.crs
+    rio_crs = rasterio.crs.CRS.from_wkt(
+        'PROJCS["unnamed",GEOGCS["Unknown datum based upon the custom spheroid",'
+        'DATUM["Not specified (based on custom spheroid)",'
+        'SPHEROID["Custom spheroid",6371007.181,0]],'
+        'PRIMEM["Greenwich",0],UNIT["degree",0.0174532925199433]],'
+        'PROJECTION["Sinusoidal"],PARAMETER["longitude_of_center",0],'
+        'PARAMETER["false_easting",0],PARAMETER["false_northing",0],'
+        'UNIT["Meter",1],AXIS["Easting",EAST],AXIS["Northing",NORTH]]'
+    )
+    assert CRS(rio_crs).epsg is None
+
+
 @pytest.mark.parametrize("left, right, off, res, expect", [
     (20, 30, 10, 0, (20, 1)),
     (20, 30.5, 10, 0, (20, 1)),
